==> haskell-citeproc-0.8.1-89-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 citeproc
version:              0.8.1
visibility:           public
id:                   citeproc-0.8.1-3nKR0wRr2t6LLZmoPqYkQe
key:                  citeproc-0.8.1-3nKR0wRr2t6LLZmoPqYkQe
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  861f11e17e57ca8f6cf5f68b3db165db
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.2.8/site-local/citeproc-0.8.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/citeproc-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.8.1-3nKR0wRr2t6LLZmoPqYkQe
depends:
    aeson-2.1.2.1-3Y7c2RiVUt62qtHv6r8uDo
    attoparsec-0.14.4-6bGZjP6ZyLf9ECb8I9ykxo base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-6iepj2tDmcw8EsjS9ZrC5G
    containers-0.6.5.1 data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND filepath-1.4.2.2
    pandoc-types-1.23.1-JhS3AH9MzzS3PuiGDmRF6Z
    safe-0.3.21-IV9JEOqgAPW5kBnD5FFjUK
    scientific-0.3.7.0-CU80SbIY3FlElsPp95sCiY text-1.2.5.0
    text-icu-0.8.0.4-yXzoakOHUaK4mgjQvsI13 transformers-0.5.6.2
    unicode-collation-0.1.3.6-G2U6bpmeJIM6FBHDwGK5pg
    uniplate-1.6.13-LchF1fuYoSd7c2OIakVYal
    vector-0.13.1.0-AXstUsf4rEVFm5YPigldNP
    xml-conduit-1.9.1.3-ENUVIwgYlXd8JTBxCuIGns

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-citeproc-0.8.1-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 citeproc
version:              0.8.1
visibility:           public
id:                   citeproc-0.8.1-1YG19Y0LaCNA5x5rU9nnvl
key:                  citeproc-0.8.1-1YG19Y0LaCNA5x5rU9nnvl
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  b4c75d2a3c16a15da56adf1fc89a6b29
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.2.8/site-local/citeproc-0.8.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/citeproc-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.8.1-1YG19Y0LaCNA5x5rU9nnvl
depends:
    aeson-2.1.2.1-7MxCVi0kerx5YLDSk2pLUu
    attoparsec-0.14.4-6bGZjP6ZyLf9ECb8I9ykxo base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-6iepj2tDmcw8EsjS9ZrC5G
    containers-0.6.5.1 data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND filepath-1.4.2.2
    pandoc-types-1.23.1-634xdowZJpAFuTepiYikBo
    safe-0.3.21-IV9JEOqgAPW5kBnD5FFjUK
    scientific-0.3.7.0-CU80SbIY3FlElsPp95sCiY text-1.2.5.0
    text-icu-0.8.0.4-yXzoakOHUaK4mgjQvsI13 transformers-0.5.6.2
    unicode-collation-0.1.3.6-G2U6bpmeJIM6FBHDwGK5pg
    uniplate-1.6.13-C2iksnRs4Af7w8GQenmUgF
    vector-0.13.1.0-AXstUsf4rEVFm5YPigldNP
    xml-conduit-1.9.1.3-7IgAhNrjU5MG04zEwyoGd8

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
